from kodexa import Document


class DocumentV3(Document):
    """
    The v3 implementation of a Kodexa document which is
    designed for high-performance and very large documents and uses
    an underlying SQLLite database to manage the storage of the
    content structure and features

    Work in Progress
    """
    pass
